==> qtjambi-script-debuginfo-macos-5.15.18.jar: sources/QtJambiScript/QScriptExtensionPlugin_shell.h <==
#ifndef QSCRIPTEXTENSIONPLUGIN_SHELL_H
#define QSCRIPTEXTENSIONPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtScript/qscriptextensionplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScript/qscriptengine.h>
#include <QtScript/qscriptvalue.h>
#include <QtJambi/RegistryAPI>


class QScriptExtensionPlugin_shell : public QScriptExtensionPlugin, public QtJambiShellInterface
{
public:
    QScriptExtensionPlugin_shell(QObject* parent0 = nullptr);
    ~QScriptExtensionPlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initialize(const QString& key0, QScriptEngine* engine1) override;
    QStringList keys() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScriptExtensionPlugin_access : public QScriptExtensionPlugin
{
    void __qt_initialize_cref_QString_QScriptEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0, QtJambiNativeID engine1);
    jobject __qt_keys(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QSCRIPTEXTENSIONPLUGIN_SHELL_H

==> qtjambi-script-debuginfo-macos-5.15.20.jar: sources/QtJambiScript/QScriptExtensionPlugin_shell.h <==
#ifndef QSCRIPTEXTENSIONPLUGIN_SHELL_H
#define QSCRIPTEXTENSIONPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtScript/qscriptextensionplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScript/qscriptengine.h>
#include <QtScript/qscriptvalue.h>
#include <QtJambi/RegistryAPI>


class QScriptExtensionPlugin_shell : public QScriptExtensionPlugin, public QtJambiShellInterface
{
public:
    QScriptExtensionPlugin_shell(QObject* parent0 = nullptr);
    ~QScriptExtensionPlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initialize(const QString& key0, QScriptEngine* engine1) override;
    QStringList keys() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScriptExtensionPlugin_access : public QScriptExtensionPlugin
{
    void __qt_initialize_cref_QString_QScriptEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0, QtJambiNativeID engine1);
    jobject __qt_keys_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QSCRIPTEXTENSIONPLUGIN_SHELL_H
